==> cost-interface-0.3.3-sources.jar: com/chinayanghe/tpm/cost/vo/in/SaleLimitProductVo.java <==
package com.chinayanghe.tpm.cost.vo.in;

import java.io.Serializable;
import java.util.Date;

/**
 * 销售限制产品明细表
 * SaleLimitDto
 * 数据库表：sale_limit
 */
public class SaleLimitProductVo implements Serializable {

	 /**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	/**
    *
    * 表字段 : sale_limit.product_id
    */
   private String productId;

   /**
    *
    * 表字段 : sale_limit.product_name
    */
   private String productName;

   /**
    * 合计审核瓶数
    * 表字段 : sale_limit.audit_pay_num
    */
   private Integer auditPayNum;

   /**
    * 合计申请瓶数
    * 表字段 : sale_limit.audit_apply_num
    */
   private Integer auditApplyNum;

   /**开票开始时间*/
   private Date    ticketStartDate;
   /**开票结束时间*/
   private Date ticketEndDate;
   /**是否是期间控制*/
   private boolean timeControl;
public String getProductId() {
	return productId;
}
public void setProductId(String productId) {
	this.productId = productId;
}
public String getProductName() {
	return productName;
}
public void setProductName(String productName) {
	this.productName = productName;
}
public Integer getAuditPayNum() {
	return auditPayNum;
}
public void setAuditPayNum(Integer auditPayNum) {
	this.auditPayNum = auditPayNum;
}
public Integer getAuditApplyNum() {
	return auditApplyNum;
}
public void setAuditApplyNum(Integer auditApplyNum) {
	this.auditApplyNum = auditApplyNum;
}
public Date getTicketStartDate() {
	return ticketStartDate;
}
public void setTicketStartDate(Date ticketStartDate) {
	this.ticketStartDate = ticketStartDate;
}
public Date getTicketEndDate() {
	return ticketEndDate;
}
public void setTicketEndDate(Date ticketEndDate) {
	this.ticketEndDate = ticketEndDate;
}
public boolean isTimeControl() {
	return timeControl;
}
public void setTimeControl(boolean timeControl) {
	this.timeControl = timeControl;
}
   
   
    
    
}

==> cost-interface-0.3.46-sources.jar: com/chinayanghe/tpm/cost/vo/in/SaleLimitProductVo.java <==
package com.chinayanghe.tpm.cost.vo.in;

import java.io.Serializable;
import java.util.Date;

/**
 * 销售限制产品明细表
 * SaleLimitDto
 * 数据库表：sale_limit
 */
public class SaleLimitProductVo implements Serializable {

	 /**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	/**
    *
    * 表字段 : sale_limit.product_id
    */
   private String productId;

   /**
    *
    * 表字段 : sale_limit.product_name
    */
   private String productName;
   /**
    * 是否可删除标示
    */
   private Integer isNewproduct;

   /**
    * 合计审核瓶数
    * 表字段 : sale_limit.audit_pay_num
    */
   private Integer auditPayNum;

   /**
    * 合计申请瓶数
    * 表字段 : sale_limit.audit_apply_num
    */
   private Integer auditApplyNum;

   /**开票开始时间*/
   private Date    ticketStartDate;
   /**开票结束时间*/
   private Date ticketEndDate;
   /**是否是期间控制*/
   private boolean timeControl;
public String getProductId() {
	return productId;
}
public void setProductId(String productId) {
	this.productId = productId;
}
public String getProductName() {
	return productName;
}
public void setProductName(String productName) {
	this.productName = productName;
}
public Integer getAuditPayNum() {
	return auditPayNum;
}
public void setAuditPayNum(Integer auditPayNum) {
	this.auditPayNum = auditPayNum;
}
public Integer getAuditApplyNum() {
	return auditApplyNum;
}
public void setAuditApplyNum(Integer auditApplyNum) {
	this.auditApplyNum = auditApplyNum;
}
public Date getTicketStartDate() {
	return ticketStartDate;
}
public void setTicketStartDate(Date ticketStartDate) {
	this.ticketStartDate = ticketStartDate;
}
public Date getTicketEndDate() {
	return ticketEndDate;
}
public void setTicketEndDate(Date ticketEndDate) {
	this.ticketEndDate = ticketEndDate;
}
public boolean isTimeControl() {
	return timeControl;
}
public void setTimeControl(boolean timeControl) {
	this.timeControl = timeControl;
}
public Integer getIsNewproduct() {
	return isNewproduct;
}
public void setIsNewproduct(Integer isNewproduct) {
	this.isNewproduct = isNewproduct;
}
   
   
    
    
}
